# TACC CMS - Templates - DjangoCMS Blog - Plugins

More than one set of `./plugins` may exist, by:
- _both_ adding a child directory within the `./plugins` directory
- _and_ updating the `BLOG_PLUGIN_TEMPLATE_FOLDERS` setting

## Reference

- [Templates](https://djangocms-blog.readthedocs.io/en/release-1.1.x/features/templates.html)
- [Settings](https://djangocms-blog.readthedocs.io/en/release-1.1.x/settings.html)
